Module json

Module json 

Serialization and deserialization of Arrow Schema to JSON.

This serialization is a convenience utility. It is not intended to be a standard serialization format for Arrow. No guarantees are made about the stability of the serialization format. Use at your own risk.

Structs

JsonDataType
JSON representation of an Apache Arrow DataType.
JsonField
JSON representation of an Apache Arrow Field.
JsonSchema
JSON representation of a Apache Arrow Schema.

Traits

ArrowJsonExt
Conversion between Arrow Schema and JSON representation (string).