pub struct BlobDescriptorArrayBuilder { /* private fields */ }Expand description
Builds physical blob descriptors for one blob v2 column.
This builder only produces the writer-side descriptor struct array. It does not allocate blob ids, choose sidecar paths, write blob objects, or commit data files.
Implementations
Sourceimpl BlobDescriptorArrayBuilder
impl BlobDescriptorArrayBuilder
Sourcepub fn new(column: impl Into<String>) -> Self
pub fn new(column: impl Into<String>) -> Self
Create a descriptor array builder for one blob column.
Sourcepub fn push_packed(&mut self, blob_id: u32, range: BlobRange) -> Result<()>
pub fn push_packed(&mut self, blob_id: u32, range: BlobRange) -> Result<()>
Append one packed blob descriptor.
Sourcepub fn extend_packed(
&mut self,
blob_id: u32,
ranges: impl IntoIterator<Item = BlobRange>,
) -> Result<()>
pub fn extend_packed( &mut self, blob_id: u32, ranges: impl IntoIterator<Item = BlobRange>, ) -> Result<()>
Append multiple packed blob descriptors for the same blob object.
Sourcepub fn push_dedicated(&mut self, blob_id: u32, size: u64) -> Result<()>
pub fn push_dedicated(&mut self, blob_id: u32, size: u64) -> Result<()>
Append one dedicated blob descriptor.
Sourcepub fn push(&mut self, value: BlobDescriptor) -> Result<()>
pub fn push(&mut self, value: BlobDescriptor) -> Result<()>
Append one blob descriptor to this column.
Sourcepub fn extend(
&mut self,
values: impl IntoIterator<Item = BlobDescriptor>,
) -> Result<()>
pub fn extend( &mut self, values: impl IntoIterator<Item = BlobDescriptor>, ) -> Result<()>
Append multiple blob descriptors to this column.
Sourcepub fn push_inline(&mut self, data: impl Into<Bytes>) -> Result<()>
pub fn push_inline(&mut self, data: impl Into<Bytes>) -> Result<()>
Append an inline blob value.
Sourcepub fn push_external(
&mut self,
uri: impl Into<String>,
range: Option<BlobRange>,
) -> Result<()>
pub fn push_external( &mut self, uri: impl Into<String>, range: Option<BlobRange>, ) -> Result<()>
Append an external blob reference.
Sourcepub fn finish(self) -> Result<BlobDescriptorColumn>
pub fn finish(self) -> Result<BlobDescriptorColumn>
Finish this column and return the writer-side descriptor struct array.