Module dataset

Module dataset 

Lance Dataset

Re-exports

pub use write::merge_insert::MergeInsertBuilder;
pub use write::merge_insert::MergeInsertJob;
pub use write::merge_insert::MergeStats;
pub use write::merge_insert::UncommittedMergeInsert;
pub use write::merge_insert::WhenMatched;
pub use write::merge_insert::WhenNotMatched;
pub use write::merge_insert::WhenNotMatchedBySource;
pub use write::update::UpdateBuilder;
pub use write::update::UpdateJob;
pub use write::AutoCleanupParams;
pub use write::CommitBuilder;
pub use write::DEFAULT_COMMIT_TIMEOUT;
pub use write::DeleteBuilder;
pub use write::DeleteResult;
pub use write::ExternalBlobMode;
pub use write::InsertBuilder;
pub use write::UncommittedDelete;
pub use write::WriteDestination;
pub use write::WriteMode;
pub use write::WriteParams;
pub use write::WriteProgressFn;
pub use write::WriteStats;
pub use write::write_fragments;Deprecated

Modules

builder
cleanup
A task to clean up a lance dataset, removing files that are no longer needed.
delta
files
Dataset file inspection APIs.
fragment
Wraps a Fragment of the dataset.
index
mem_wal
MemWAL - Log-Structured Merge (LSM) tree for Lance tables
optimize
Table maintenance for optimizing table layout.
progress
refs
rowids
scanner
sql
statistics
Module for statistics related to the dataset.
transaction
Transaction definitions for updating datasets
udtf
updater
write

Structs

BatchInfo
BatchUDF
BlobFile
A file-like object that represents a blob in a dataset
BlobRangeRequest
One row-specific blob range read request.
BlobReadRange
A byte range relative to the beginning of one logical blob value.
ColumnAlteration
Definition of a change to a column in a dataset
Dataset
Lance Dataset
ReadBlob
Blob bytes materialized by ReadBlobsBuilder.
ReadBlobRange
Bytes materialized for one request submitted through ReadBlobRangesBuilder.
ReadBlobRangesBuilder
Builder for planned blob-local range reads.
ReadBlobsBuilder
Builder for sequential / planned blob reads.
ReadParams
Customize read behavior of a dataset.
TakeBuilder
Builder for the take operation.
Version
Dataset Version
VersionTransaction
The transaction that produced a version of the dataset, along with the version’s commit timestamp.

Enums

NewColumnTransform
A way to define one or more new columns in a dataset
ProjectionRequest

Constants

DEFAULT_INDEX_CACHE_SIZE
DEFAULT_METADATA_CACHE_SIZE
ROW_ID
Column name for the meta row ID.

Traits

UDFCheckpointStore
A mechanism for saving UDF results.

Type Aliases

ReadBlobRangesStream
Stream returned by ReadBlobRangesBuilder::try_into_stream.
ReadBlobsStream
Stream returned by ReadBlobsBuilder::try_into_stream.