CleanupPolicy

Struct CleanupPolicy 

pub struct CleanupPolicy {
    pub before_timestamp: Option<DateTime<Utc>>,
    pub before_version: Option<u64>,
    pub delete_unverified: bool,
    pub error_if_tagged_old_versions: bool,
    pub clean_referenced_branches: bool,
    pub delete_rate_limit: Option<u64>,
}

Fields

before_timestamp: Option<DateTime<Utc>>

If not none, cleanup all versions before the specified timestamp.

before_version: Option<u64>

If not none, cleanup all versions before the specified version.

delete_unverified: bool

If true, delete unverified data files even if they are recent

error_if_tagged_old_versions: bool

If true, return an Error if a tagged version is old

clean_referenced_branches: bool

If clean the referenced branches

delete_rate_limit: Option<u64>

Maximum number of delete requests per second. If None, no rate limiting is applied.

Use this to avoid hitting S3 (or other object store) request rate limits during cleanup. On stores with bulk delete, each request can include multiple paths. For example, Some(100) limits deletions to 100 delete requests per second.

Implementations

Source

impl CleanupPolicy

pub fn should_clean(&self, manifest: &Manifest) -> bool