Module remapping

Module remapping 

Utilities for remapping row ids. Necessary before stable row ids.

Structs

IgnoreRemap
RemappedIndex
A remapped index

Enums

RemapResult
The result of remapping an index

Traits

IndexRemapper
When compaction runs the row ids will change. This typically means that indices will need to be remapped. The details of how this happens are not a part of the compaction process and so a trait is defined here to allow for inversion of control.
IndexRemapperOptions
Options for creating an IndexRemapper

Functions

remap_column_index
transpose_row_addrs
transpose_row_ids_from_digest