pub struct BranchIdentifier {
pub version_mapping: Vec<(u64, String)>,
}Fields
version_mapping: Vec<(u64, String)>Implementations
Sourceimpl BranchIdentifier
impl BranchIdentifier
pub fn new(parent: &Self, parent_version: u64) -> Self
Sourcepub fn none() -> Self
pub fn none() -> Self
Creates a branch identifier for legacy branches without explicit lineage. Legacy branches have parent_version=0 and are skipped during cleanup.
pub fn main() -> Self
pub fn parse(identifier: &str) -> Result<Self>
pub fn find_referenced_version(&self, referenced_branch: &Self) -> Option<u64>
Sourcepub fn collect_referenced_versions(
&self,
branches: &HashMap<String, BranchContents>,
) -> Vec<(String, u64)>
pub fn collect_referenced_versions( &self, branches: &HashMap<String, BranchContents>, ) -> Vec<(String, u64)>
Collects all branches that reference this branch, returning (branch_name, version) tuples. Results are in post-order traversal (deepest branches first).