pub struct SqlQueryBuilder { /* private fields */ }Expand description
A SQL builder to prepare options for running SQL queries against a Lance dataset.
Implementations
Sourceimpl SqlQueryBuilder
impl SqlQueryBuilder
pub fn new(dataset: Dataset, sql: &str) -> Self
Sourcepub fn table_name(self, table_name: &str) -> Self
pub fn table_name(self, table_name: &str) -> Self
The table name to register in the datafusion context. This is used to specify a “table name” for the dataset. So that you can run SQL queries against it. If not set, the default table name is “dataset”.
Sourcepub fn with_row_id(self, row_id: bool) -> Self
pub fn with_row_id(self, row_id: bool) -> Self
Specify if the query result should include the internal row id. If true, the query result will include an additional column named “_rowid”.
Sourcepub fn with_row_addr(self, row_addr: bool) -> Self
pub fn with_row_addr(self, row_addr: bool) -> Self
Specify if the query result should include the internal row address. If true, the query result will include an additional column named “_rowaddr”.
pub async fn build(self) -> Result<SqlQuery>