pub struct UpdateBuilder { /* private fields */ }Expand description
Build an update operation.
This operation is similar to SQL’s UPDATE statement. It allows you to change the values of all or a subset of columns with SQL expressions.
Use the UpdateBuilder to construct an update job. For example:
let result = UpdateBuilder::new(dataset)
.update_where("region_id = 10")?
.set("region_name", "New York")?
.build()?
.execute()
.await?;Implementations
Sourceimpl UpdateBuilder
impl UpdateBuilder
pub fn new(dataset: Arc<Dataset>) -> Self
pub fn update_where(self, filter: &str) -> Result<Self>
pub fn set(self, column: impl AsRef<str>, value: &str) -> Result<Self>
Sourcepub fn conflict_retries(self, retries: u32) -> Self
pub fn conflict_retries(self, retries: u32) -> Self
Set the number of times to retry on commit conflicts.
Default is 10.
Sourcepub fn retry_timeout(self, timeout: Duration) -> Self
pub fn retry_timeout(self, timeout: Duration) -> Self
Set the total timeout for all retries.
Default is 30 seconds.
pub fn build(self) -> Result<UpdateJob>