pub struct InsertBuilder<'a> { /* private fields */ }Expand description
Insert or create a new dataset.
There are different variants of execute() methods. Those with the _stream
suffix take an iterator of data so that larger than memory data can be written
out. However, this eliminates optimizations that can be made when the full
data is known up-front.
Those with the _uncommitted suffix write the data files but do not commit
the transactions. These changes to the dataset will not be visible until
they are passed to the CommitBuilder.
Implementations
Sourceimpl<'a> InsertBuilder<'a>
impl<'a> InsertBuilder<'a>
pub fn new(dest: impl Into<WriteDestination<'a>>) -> Self
pub fn with_params(self, params: &'a WriteParams) -> Self
Sourcepub fn progress(
self,
callback: impl Fn(WriteStats) + Send + Sync + 'static,
) -> Self
pub fn progress( self, callback: impl Fn(WriteStats) + Send + Sync + 'static, ) -> Self
Register a callback that is invoked after each batch of rows is written.
The callback receives cumulative WriteStats and can be used to drive
a progress bar or compute throughput. It must be cheap and non-blocking;
spawn a task if you need async work.
This overrides any write_progress set in WriteParams.
Sourcepub async fn execute(&self, data: Vec<RecordBatch>) -> Result<Dataset>
pub async fn execute(&self, data: Vec<RecordBatch>) -> Result<Dataset>
Execute the insert operation with the given data.
This writes the data fragments and commits them into the dataset.
Sourcepub async fn execute_stream(
&self,
source: impl StreamingWriteSource,
) -> Result<Dataset>
pub async fn execute_stream( &self, source: impl StreamingWriteSource, ) -> Result<Dataset>
Execute the insert operation with the given stream.
This writes the data fragments and commits them into the dataset.
Sourcepub async fn execute_uncommitted(
&self,
data: Vec<RecordBatch>,
) -> Result<Transaction>
pub async fn execute_uncommitted( &self, data: Vec<RecordBatch>, ) -> Result<Transaction>
Write data files, but don’t commit the transaction yet.
Use CommitBuilder to commit the transaction.
Example: Append data to a dataset
use lance::dataset::{CommitBuilder, InsertBuilder, WriteMode, WriteParams};
let transaction = InsertBuilder::new(dataset.clone())
.with_params(&WriteParams { mode: WriteMode::Append, ..Default::default() })
.execute_uncommitted(data)
.await?;
CommitBuilder::new(dataset)
.execute(transaction)
.await?;Sourcepub async fn execute_uncommitted_stream(
&self,
source: impl StreamingWriteSource,
) -> Result<Transaction>
pub async fn execute_uncommitted_stream( &self, source: impl StreamingWriteSource, ) -> Result<Transaction>
Write data files, but don’t commit the transaction yet.
Use CommitBuilder to commit the transaction.