Projection

Struct Projection 

pub struct Projection {
    pub field_ids: HashSet<i32>,
    pub with_row_id: bool,
    pub with_row_addr: bool,
    pub with_row_last_updated_at_version: bool,
    pub with_row_created_at_version: bool,
    pub blob_handling: BlobHandling,
    /* private fields */
}
A projection is a selection of fields in a schema

In addition we record whether the row_id or row_addr are selected (these fields have no field id)

Fields

field_ids: HashSet<i32>with_row_id: boolwith_row_addr: boolwith_row_last_updated_at_version: boolwith_row_created_at_version: boolblob_handling: BlobHandling

Implementations

Source

impl Projection

pub fn empty(base: Arc<dyn Projectable>) -> Projection

Create a new empty projection

pub fn full(base: Arc<dyn Projectable>) -> Projection

pub fn with_row_id(self) -> Projection

pub fn with_row_addr(self) -> Projection

pub fn with_row_last_updated_at_version(self) -> Projection

pub fn with_row_created_at_version(self) -> Projection

pub fn with_blob_handling(self, blob_handling: BlobHandling) -> Projection

pub fn union_column( self, column: impl AsRef<str>, on_missing: OnMissing, ) -> Result<Projection, Error>

Add a column to the projection from a string reference

The string reference can be a dotted field path (x.y.z) to reference inner struct fields

Parent fields will automatically be added. If the specified field has any children then those will be added to. Siblings, aunts, etc. are not automatically added

pub fn contains_field_id(&self, id: i32) -> bool

True if the projection selects the given field id

pub fn has_data_fields(&self) -> bool

True if the projection selects fields other than the row id / addr

pub fn union_columns( self, columns: impl IntoIterator<Item = impl AsRef<str>>, on_missing: OnMissing, ) -> Result<Projection, Error>

Add multiple columns (and their parents) to the projection

pub fn union_predicate(self, predicate: impl Fn(&Field) -> bool) -> Projection

Adds all fields from the base schema satisfying a predicate

pub fn subtract_predicate( self, predicate: impl Fn(&Field) -> bool, ) -> Projection

Removes all fields in the base schema satisfying a predicate

pub fn intersect(self, other: &Projection) -> Projection

Creates a new projection that is the intersection of this projection and another

pub fn union_schema(self, other: &Schema) -> Projection

Adds all fields from the provided schema to the projection

Fields are only added if they exist in the base schema, otherwise they are ignored.

Will panic if a field in the given schema has a non-negative id and is not in the base schema.

pub fn union_projection(self, other: &Projection) -> Projection

Creates a new projection that is the union of this projection and another

pub fn union_arrow_schema( self, other: &Schema, on_missing: OnMissing, ) -> Result<Projection, Error>

Adds all fields from the given schema to the projection

on_missing controls what happen to fields that are not in the base schema

Name based matching is used to determine if a field is in the base schema.

pub fn subtract_arrow_schema( self, other: &Schema, on_missing: OnMissing, ) -> Result<Projection, Error>

Removes all fields from the projection that are in the given schema

on_missing controls what happen to fields that are not in the base schema

Name based matching is used to determine if a field is in the base schema.

pub fn subtract_projection(self, other: &Projection) -> Projection

Removes all fields from this projection that are present in the given projection

pub fn subtract_schema(self, other: &Schema) -> Projection

Removes all fields from the projection that are in the given schema

Fields are only removed if they exist in the base schema, otherwise they are ignored.

Will panic if a field in the given schema has a non-negative id and is not in the base schema.

pub fn is_empty(&self) -> bool

True if the projection does not select any fields or take the row id / addr

pub fn is_metadata_only(&self) -> bool

True if the projection is only the row_id or row_addr columns

Note: this will return false for a completely empty projection

pub fn has_non_meta_cols(&self) -> bool

True if the projection has at least one non-metadata column

pub fn to_bare_schema(&self) -> Schema

Convert the projection to a schema that does not include metadata columns

pub fn to_schema(&self) -> Schema

Convert the projection to a schema

Includes the _rowid and _rowaddr columns if requested

pub fn into_schema(self) -> Schema

Convert the projection to a schema

pub fn into_schema_ref(self) -> Arc<Schema>

Convert the projection to a schema reference

pub fn to_arrow_schema(&self) -> Schema

Convert the projection into an Arrow schema