Secondary Index
Modules
- frag_
reuse - mem_wal
- MemWAL Index operations.
- prefilter
- Secondary Index pre-filter
- scalar
- Utilities for integrating scalar indices with datasets
- vector
- Vector Index for Fast Approximate Nearest Neighbor (ANN) Search
Structs
- Create
Index Builder - Frag
Reuse Index Cache Key - MemWal
Cache Key - Noop
Index Build Progress - Scalar
Index Cache Key - Scalar
Index Info - Vector
Index Cache Key
Traits
- Dataset
Index Internal Ext - A trait for internal dataset utilities
- Filter
Loader - A trait to be implemented by anything supplying a prefilter row addr mask
- Index
Build Progress - Progress callback for index building.
- Index
Builder - Builds index.
- Index
Params - PreFilter
- Filter out row ids that we know are not relevant to the query.