Module vector

Module vector 

Vector Index for Fast Approximate Nearest Neighbor (ANN) Search

Modules

builder
ivf
IVF - Inverted File index.
pq
utils

Structs

LogicalIvfView
An IVF-specific inspection and maintenance view over a LogicalVectorIndex.
LogicalVectorIndex
A materialized snapshot of one logical vector index and all of its segments.
VectorIndexParams
The parameters to build vector index.

Enums

IndexFileVersion
StageParams
Parameters of each index stage.

Constants

LANCE_VECTOR_INDEX

Functions

initialize_vector_index
Initialize a vector index from a source dataset This will reuse the centroids from the source dataset, making the new indices basically a “delta index” of the source dataset, until the new dataset fully retains the index.