pub struct LogicalVectorIndex { /* private fields */ }Expand description
A materialized snapshot of one logical vector index and all of its segments.
Implementations
Sourceimpl LogicalVectorIndex
impl LogicalVectorIndex
Sourcepub fn num_segments(&self) -> usize
pub fn num_segments(&self) -> usize
Returns the number of physical segments in this logical index.
Sourcepub fn metadatas(&self) -> impl ExactSizeIterator<Item = &IndexMetadata> + '_
pub fn metadatas(&self) -> impl ExactSizeIterator<Item = &IndexMetadata> + '_
Returns the committed metadata for all physical segments.
Sourcepub fn num_rows_per_segment(&self) -> Vec<(Uuid, u64)>
pub fn num_rows_per_segment(&self) -> Vec<(Uuid, u64)>
Returns the indexed row count for each segment.
Sourcepub fn as_ivf(&self) -> Result<LogicalIvfView<'_>>
pub fn as_ivf(&self) -> Result<LogicalIvfView<'_>>
Returns an IVF view over this logical index.
This is currently fallible only to leave room for future non-IVF vector index families. All vector indices currently opened through this path are IVF-backed.