Module exec

Module exec 

Execution nodes

WARNING: Internal API with no stability guarantees.

Re-exports

pub use utils::PreFilterSource;

Modules

filtered_read
fts
scalar_index
utils

Structs

ANNIvfPartitionExec
ExecutionPlan to execute the find the closest IVF partitions.
ANNIvfSubIndexExec
Datafusion ExecutionPlan to run search on vector index partitions.
AddRowAddrExec
Add a _rowaddr column to a stream of record batches that have a _rowid.
AddRowOffsetExec
Add a _rowoffset column to a stream of record batches that have a _rowaddr column.
FilterPlan
KNNVectorDistanceExec
ExecutionPlan compute vector distance from a query vector.
LanceFilterExec
LancePushdownScanExec
LanceScanConfig
LanceScanExec
DataFusion ExecutionPlan for scanning one Lance dataset
Planner
ScanConfig
TakeExec

Functions

get_physical_optimizer
project
Make a DataFusion projection node from a schema.