ObjectStoreRegistry

Struct ObjectStoreRegistry 

pub struct ObjectStoreRegistry { /* private fields */ }
A registry of object store providers.

Use Self::default() to create one with the available default providers. This includes (depending on features enabled):

  • memory: An in-memory object store.
  • file: A local file object store, with optimized code paths.
  • file-object-store: A local file object store that uses the ObjectStore API, for all operations. Used for testing with ObjectStore wrappers.
  • s3: An S3 object store.
  • s3+ddb: An S3 object store with DynamoDB for metadata.
  • az: An Azure Blob Storage object store.
  • gs: A Google Cloud Storage object store.

Use Self::empty() to create an empty registry, with no providers registered.

The registry also caches object stores that are currently in use. It holds weak references to the object stores, so they are not held onto. If an object store is no longer in use, it will be removed from the cache on the next call to either Self::active_stores() or Self::get_store().

Implementations

Source

impl ObjectStoreRegistry

pub fn empty() -> ObjectStoreRegistry

Create a new registry with no providers registered.

Typically, you want to use Self::default() instead, so you get the default providers.

pub fn get_provider(&self, scheme: &str) -> Option<Arc<dyn ObjectStoreProvider>>

Get the object store provider for a given scheme.

pub fn active_stores(&self) -> Vec<Arc<ObjectStore>>

Get a list of all active object stores.

Calling this will also clean up any weak references to object stores that are no longer valid.

pub fn stats(&self) -> ObjectStoreRegistryStats

Get cache statistics for monitoring and debugging.

Returns the number of cache hits, misses, and currently active stores. This is useful for detecting configuration issues that cause excessive cache misses (e.g., storage options that vary per-request).

pub async fn get_store( &self, base_path: Url, params: &ObjectStoreParams, ) -> Result<Arc<ObjectStore>, Error>

Get an object store for a given base path and parameters.

If the object store is already in use, it will return a strong reference to the object store. If the object store is not in use, it will create a new object store and return a strong reference to it.

pub fn calculate_object_store_prefix( &self, uri: &str, storage_options: Option<&HashMap<String, String>>, ) -> Result<String, Error>

Calculate the datastore prefix based on the URI and the storage options. The data store prefix should uniquely identify the datastore.

Source

impl ObjectStoreRegistry

pub fn insert(&self, scheme: &str, provider: Arc<dyn ObjectStoreProvider>)

Add a new object store provider to the registry. The provider will be used in Self::get_store() when a URL is passed with a matching scheme.