pub struct IndexMetadata {
pub uuid: Uuid,
pub fields: Vec<i32>,
pub name: String,
pub dataset_version: u64,
pub fragment_bitmap: Option<RoaringBitmap>,
pub index_details: Option<Arc<Any>>,
pub index_version: i32,
pub created_at: Option<DateTime<Utc>>,
pub base_id: Option<u32>,
pub files: Option<Vec<IndexFile>>,
}Expand description
Index metadata
Fields
uuid: UuidUnique ID across all dataset versions.
fields: Vec<i32>Fields to build the index.
name: StringHuman readable index name
dataset_version: u64The version of the dataset this index was last updated on
This is set when the index is created (based on the version used to train the index) This is updated when the index is updated or remapped
fragment_bitmap: Option<RoaringBitmap>The fragment ids this index covers.
This may contain fragment ids that no longer exist in the dataset.
If this is None, then this is unknown.
index_details: Option<Arc<Any>>Metadata specific to the index type
This is an Option because older versions of Lance may not have this defined. However, it should always be present in newer versions.
index_version: i32The index version.
created_at: Option<DateTime<Utc>>Timestamp when the index was created
This field is optional for backward compatibility. For existing indices created before this field was added, this will be None.
base_id: Option<u32>The base path index of the index files. Used when the index is imported or referred from another dataset. Lance uses it as key of the base_paths field in Manifest to determine the actual base path of the index files.
files: Option<Vec<IndexFile>>List of files and their sizes for this index segment. This enables skipping HEAD calls when opening indices and provides visibility into index storage size via describe_indices(). This is None if the file sizes are unknown. This happens for indices created before this field was added.
Implementations
Sourceimpl IndexMetadata
impl IndexMetadata
pub fn effective_fragment_bitmap( &self, existing_fragments: &RoaringBitmap, ) -> Option<RoaringBitmap>
Sourcepub fn file_size_map(&self) -> HashMap<String, u64>
pub fn file_size_map(&self) -> HashMap<String, u64>
Returns a map of relative file paths to their sizes. Returns an empty map if file information is not available.
Sourcepub fn total_size_bytes(&self) -> Option<u64>
pub fn total_size_bytes(&self) -> Option<u64>
Returns the total size of all files in this index segment in bytes. Returns None if file information is not available.
Sourcepub fn deleted_fragment_bitmap(
&self,
existing_fragments: &RoaringBitmap,
) -> Option<RoaringBitmap>
pub fn deleted_fragment_bitmap( &self, existing_fragments: &RoaringBitmap, ) -> Option<RoaringBitmap>
Returns the set of fragments which are part of the fragment bitmap but no longer in the dataset.