pub struct WriterVersion {
pub library: String,
pub version: String,
pub prerelease: Option<String>,
pub build_metadata: Option<String>,
}Fields
library: Stringversion: Stringprerelease: Option<String>build_metadata: Option<String>Implementations
Sourceimpl WriterVersion
impl WriterVersion
Sourcepub fn semver(&self) -> Option<(u32, u32, u32, Option<&str>)>
👎Deprecated: Use lance_lib_version() instead
pub fn semver(&self) -> Option<(u32, u32, u32, Option<&str>)>
lance_lib_version() insteadTry to parse the version string as a semver string. Returns None if not successful.
Sourcepub fn lance_lib_version(&self) -> Option<Version>
pub fn lance_lib_version(&self) -> Option<Version>
If the library is “lance”, parse the version as semver and return it. Returns None if the library is not “lance” or the version cannot be parsed as semver.
This method reconstructs the full semantic version by combining the version field with the prerelease and build_metadata fields (if present). For example:
- version=“2.0.0” + prerelease=Some(“rc.1”) -> “2.0.0-rc.1”
- version=“2.0.0” + prerelease=Some(“rc.1”) + build_metadata=Some(“build.123”) -> “2.0.0-rc.1+build.123”
pub fn semver_or_panic(&self) -> (u32, u32, u32, Option<&str>)
👎Deprecated: Use
lance_lib_version() instead, which safely checks the library field and returns OptionSourcepub fn older_than(&self, major: u32, minor: u32, patch: u32) -> bool
👎Deprecated: Use lance_lib_version() and its older_than method instead.
pub fn older_than(&self, major: u32, minor: u32, patch: u32) -> bool
lance_lib_version() and its older_than method instead.Check if this is a Lance library version older than the given major/minor/patch.
Panics
Panics if the library is not “lance” or the version cannot be parsed as semver.
pub fn bump(&self, part: VersionPart, keep_tag: bool) -> WriterVersion
👎Deprecated: This is meant for testing and will be made private in future version.