Serialization and deserialization of Arrow Schema to JSON.
This serialization is a convenience utility. It is not intended to be a standard serialization format for Arrow. No guarantees are made about the stability of the serialization format. Use at your own risk.
Structs
- Json
Data Type - JSON representation of an Apache Arrow DataType.
- Json
Field - JSON representation of an Apache Arrow Field.
- Json
Schema - JSON representation of a Apache Arrow Schema.
Traits
- Arrow
Json Ext - Conversion between Arrow Schema and JSON representation (string).