Lance Dataset
Re-exports
pub use write::merge_insert::MergeInsertBuilder;pub use write::merge_insert::MergeInsertJob;pub use write::merge_insert::MergeStats;pub use write::merge_insert::UncommittedMergeInsert;pub use write::merge_insert::WhenMatched;pub use write::merge_insert::WhenNotMatched;pub use write::merge_insert::WhenNotMatchedBySource;pub use write::update::UpdateBuilder;pub use write::update::UpdateJob;pub use write::AutoCleanupParams;pub use write::CommitBuilder;pub use write::DEFAULT_COMMIT_TIMEOUT;pub use write::DeleteBuilder;pub use write::DeleteResult;pub use write::ExternalBlobMode;pub use write::InsertBuilder;pub use write::UncommittedDelete;pub use write::WriteDestination;pub use write::WriteMode;pub use write::WriteParams;pub use write::WriteProgressFn;pub use write::WriteStats;pub use write::write_fragments;Deprecated
Modules
- builder
- cleanup
- A task to clean up a lance dataset, removing files that are no longer needed.
- delta
- files
- Dataset file inspection APIs.
- fragment
- Wraps a Fragment of the dataset.
- index
- mem_wal
- MemWAL - Log-Structured Merge (LSM) tree for Lance tables
- optimize
- Table maintenance for optimizing table layout.
- progress
- refs
- rowids
- scanner
- sql
- statistics
- Module for statistics related to the dataset.
- transaction
- Transaction definitions for updating datasets
- udtf
- updater
- write
Structs
- Batch
Info - BatchUDF
- Blob
File - A file-like object that represents a blob in a dataset
- Blob
Range Request - One row-specific blob range read request.
- Blob
Read Range - A byte range relative to the beginning of one logical blob value.
- Column
Alteration - Definition of a change to a column in a dataset
- Dataset
- Lance Dataset
- Read
Blob - Blob bytes materialized by
ReadBlobsBuilder. - Read
Blob Range - Bytes materialized for one request submitted through
ReadBlobRangesBuilder. - Read
Blob Ranges Builder - Builder for planned blob-local range reads.
- Read
Blobs Builder - Builder for sequential / planned blob reads.
- Read
Params - Customize read behavior of a dataset.
- Take
Builder - Builder for the
takeoperation. - Version
- Dataset Version
- Version
Transaction - The transaction that produced a version of the dataset, along with the version’s commit timestamp.
Enums
- NewColumn
Transform - A way to define one or more new columns in a dataset
- Projection
Request
Constants
- DEFAULT_
INDEX_ CACHE_ SIZE - DEFAULT_
METADATA_ CACHE_ SIZE - ROW_ID
- Column name for the meta row ID.
Traits
- UDFCheckpoint
Store - A mechanism for saving UDF results.
Type Aliases
- Read
Blob Ranges Stream - Stream returned by
ReadBlobRangesBuilder::try_into_stream. - Read
Blobs Stream - Stream returned by
ReadBlobsBuilder::try_into_stream.