Module dataset

Module dataset 

Lance Dataset

Re-exports

pub use write::merge_insert::MergeInsertBuilder;
pub use write::merge_insert::MergeInsertJob;
pub use write::merge_insert::MergeStats;
pub use write::merge_insert::UncommittedMergeInsert;
pub use write::merge_insert::WhenMatched;
pub use write::merge_insert::WhenNotMatched;
pub use write::merge_insert::WhenNotMatchedBySource;
pub use write::update::UpdateBuilder;
pub use write::update::UpdateJob;
pub use write::AutoCleanupParams;
pub use write::CommitBuilder;
pub use write::DeleteBuilder;
pub use write::DeleteResult;
pub use write::InsertBuilder;
pub use write::WriteDestination;
pub use write::WriteMode;
pub use write::WriteParams;
pub use write::write_fragments;Deprecated

Modules

builder
cleanup
A task to clean up a lance dataset, removing files that are no longer needed.
delta
fragment
Wraps a Fragment of the dataset.
index
mem_wal
MemWAL - Log-Structured Merge (LSM) tree for Lance tables
optimize
Table maintenance for optimizing table layout.
progress
refs
scanner
sql
statistics
Module for statistics related to the dataset.
transaction
Transaction definitions for updating datasets
udtf
updater
write

Structs

BatchInfo
BatchUDF
BlobFile
A file-like object that represents a blob in a dataset
ColumnAlteration
Definition of a change to a column in a dataset
Dataset
Lance Dataset
ReadParams
Customize read behavior of a dataset.
TakeBuilder
Builder for the take operation.
Version
Dataset Version

Enums

NewColumnTransform
A way to define one or more new columns in a dataset
ProjectionRequest

Constants

DEFAULT_INDEX_CACHE_SIZE
DEFAULT_METADATA_CACHE_SIZE
ROW_ID
Column name for the meta row ID.

Traits

UDFCheckpointStore
A mechanism for saving UDF results.