Utilities for remapping row ids. Necessary before stable row ids.
Structs
- Ignore
Remap - Remapped
Index - A remapped index
Enums
- Remap
Result - The result of remapping an index
Traits
- Index
Remapper - When compaction runs the row ids will change. This typically means that indices will need to be remapped. The details of how this happens are not a part of the compaction process and so a trait is defined here to allow for inversion of control.
- Index
Remapper Options - Options for creating an IndexRemapper