pub enum MaterializationStyle {
Heuristic,
AllLate,
AllEarly,
AllEarlyExcept(Vec<u32>),
}Expand description
Materialization style for the scanner
This only affects columns that are not used in a filter
Early materialization will fetch the entire column and throw away the rows that are not needed. This fetches more data but uses fewer I/O requests.
Late materialization will only fetch the rows that are needed. This fetches less data but uses more I/O requests.
This parameter only affects scans. Vector search and full text search always use late materialization.
Variants
Heuristic
Heuristic-based materialization style
The default approach depends on the type of object storage. For cloud storage (e.g. S3, GCS, etc.) we only use late materialization for columns that are more than 1000 bytes in size.
For local storage we use late materialization for columns that are more than 10 bytes in size.
These values are based on experimentation and the assumption that a filter will be selecting ~0.1% of the rows in a column.
AllLate
All columns will be fetched with late materialization where possible
AllEarly
All columns will be fetched with early materialization where possible
AllEarlyExcept(Vec<u32>)
All columns will be fetched with late materialization except for the specified columns
Implementations