pub struct BlobFile { /* private fields */ }Expand description
A file-like object that represents a blob in a dataset
Implementations
Sourceimpl BlobFile
impl BlobFile
Sourcepub fn new_inline(
dataset: Arc<Dataset>,
field_id: u32,
row_addr: u64,
position: u64,
size: u64,
) -> Self
pub fn new_inline( dataset: Arc<Dataset>, field_id: u32, row_addr: u64, position: u64, size: u64, ) -> Self
Create a new BlobFile
pub fn new_dedicated(dataset: Arc<Dataset>, path: Path, size: u64) -> Self
pub fn new_packed( dataset: Arc<Dataset>, path: Path, position: u64, size: u64, ) -> Self
pub async fn new_external( uri: String, size: u64, registry: Arc<ObjectStoreRegistry>, params: Arc<ObjectStoreParams>, ) -> Result<Self>
Sourcepub async fn close(&self) -> Result<()>
pub async fn close(&self) -> Result<()>
Close the blob file, releasing any associated resources
Sourcepub async fn read(&self) -> Result<Bytes>
pub async fn read(&self) -> Result<Bytes>
Read the entire blob file from the current cursor position to the end of the file
After this call the cursor will be pointing to the end of the file.
Sourcepub async fn read_up_to(&self, len: usize) -> Result<Bytes>
pub async fn read_up_to(&self, len: usize) -> Result<Bytes>
Read up to len bytes from the current cursor position
After this call the cursor will be pointing to the end of the read data.
Sourcepub async fn seek(&self, new_cursor: u64) -> Result<()>
pub async fn seek(&self, new_cursor: u64) -> Result<()>
Seek to a new cursor position in the file
pub fn position(&self) -> u64
pub fn data_path(&self) -> &Path
pub fn kind(&self) -> BlobKind
pub fn uri(&self) -> Option<&str>