Structs
- Dictionary
- Field
- Lance Schema Field
- Logical
Type - LogicalType is a string presentation of arrow type. to be serialized into protobuf.
- Projection
- A projection is a selection of fields in a schema
- Schema
- Lance Schema.
- Schema
Compare Options
Enums
- Blob
Handling - Specifies how to handle blob columns when projecting
- Blob
Kind - Physical storage mode for blob v2 descriptors (one byte, stored in the packed struct column).
- Blob
Version - Blob column format version.
- Encoding
- Encoding enum.
- Field
Ref - Reference to a field in a schema, either by ID or by path.
- Nullability
Comparison - OnMissing
- What to do when a column is missing in the schema
- OnType
Mismatch - What to do on a merge operation if the types of the fields don’t match
Constants
- BLOB_
LOGICAL_ TYPE - LANCE_
UNENFORCED_ CLUSTERING_ KEY_ POSITION - Use this config key in Arrow field metadata to specify the position of a clustering key column. The value is a 1-based integer indicating the order within the composite clustering key. Clustering key fields are ordered by this position value.
- LANCE_
UNENFORCED_ PRIMARY_ KEY - Use this config key in Arrow field metadata to indicate a column is a part of the primary key.
The value can be any true values like
true,1,yes(case-insensitive). A primary key column must satisfy: (1) The field, and all its ancestors must not be nullable. (2) The field must be a leaf without child (i.e. it is a primitive data type). (3) The field must not be within a list type. - LANCE_
UNENFORCED_ PRIMARY_ KEY_ POSITION - Use this config key in Arrow field metadata to specify the position of a primary key column. The value is a 1-based integer indicating the order within the composite primary key. When specified, primary key fields are ordered by this position value. When not specified, primary key fields are ordered by their schema field id.
Statics
- BLOB_
DESC_ FIELD - BLOB_
DESC_ FIELDS - BLOB_
DESC_ LANCE_ FIELD - BLOB_
DESC_ TYPE - BLOB_
V2_ DESC_ FIELD - BLOB_
V2_ DESC_ FIELDS - BLOB_
V2_ DESC_ LANCE_ FIELD - BLOB_
V2_ DESC_ TYPE - BLOB_
V2_ USER_ FIELDS - Blob v2 user-view struct fields used by internal rewrite paths.
- BLOB_
V2_ USER_ TYPE - Blob v2 user-view struct type used by internal rewrite paths.
Traits
- Projectable
- A trait for something that we can project fields from.
Functions
- escape_
field_ path_ for_ project - Escape a field path for project
- format_
field_ path - Format a field path, quoting field names that require escaping.
- format_
field_ path_ minimal - Like
format_field_path, but quotes a segment only when strictly required for the result to round-trip back throughparse_field_path. - parse_
field_ path - Parse a field path that may contain quoted field names.
- validate_
fixed_ size_ list_ dimensions - Reject
FixedSizeListtypes whose dimension is not a positive integer.