Module datatypes

Module datatypes 

Lance data types, Schema and Field

Structs

Dictionary
Field
Lance Schema Field
LogicalType
LogicalType is a string presentation of arrow type. to be serialized into protobuf.
Projection
A projection is a selection of fields in a schema
Schema
Lance Schema.
SchemaCompareOptions

Enums

BlobHandling
Specifies how to handle blob columns when projecting
BlobKind
Physical storage mode for blob v2 descriptors (one byte, stored in the packed struct column).
BlobVersion
Blob column format version.
Encoding
Encoding enum.
FieldRef
Reference to a field in a schema, either by ID or by path.
NullabilityComparison
OnMissing
What to do when a column is missing in the schema
OnTypeMismatch
What to do on a merge operation if the types of the fields don’t match

Constants

BLOB_LOGICAL_TYPE

Statics

BLOB_DESC_FIELD
BLOB_DESC_FIELDS
BLOB_DESC_LANCE_FIELD
BLOB_DESC_TYPE
BLOB_V2_DESC_FIELD
BLOB_V2_DESC_FIELDS
BLOB_V2_DESC_LANCE_FIELD
BLOB_V2_DESC_TYPE

Traits

Projectable
A trait for something that we can project fields from.

Functions

escape_field_path_for_project
Escape a field path for project
format_field_path
Format a field path, quoting field names that require escaping.
lance_supports_nulls
Returns true if Lance supports writing this datatype with nulls.
parse_field_path
Parse a field path that may contain quoted field names.