Struct lance::datatypes::Schema

source ·
pub struct Schema {
    pub fields: Vec<Field>,
    pub metadata: HashMap<String, String>,
}
Lance Schema.

Fields

fields: Vec<Field>

Top-level fields in the dataset.

metadata: HashMap<String, String>

Metadata of the schema

Implementations

source

impl Schema

source

pub fn project<T: AsRef<str>>(&self, columns: &[T]) -> Result<Self>

Project the columns over the schema.

let schema = Schema::from(...);
let projected = schema.project(&["col1", "col2.sub_col3.field4"])?;
source

pub fn intersection(&self, other: &Self) -> Result<Self>

Intersection between two Schema.

source

pub fn project_by_ids(&self, column_ids: &[i32]) -> Self

Returns a new schema that only contains the fields in column_ids.

This projection can filter out both top-level and nested fields

source

pub fn project_by_schema<S: TryInto<Self, Error = Error>>( &self, projection: S ) -> Result<Self>

Project the schema by another schema, and preserves field metadata, i.e., Field IDs.

Parameters

source

pub fn exclude<T: TryInto<Self> + Debug>(&self, schema: T) -> Result<Self>

Exclude the fields from other Schema, and returns a new Schema.

source

pub fn field(&self, name: &str) -> Option<&Field>

Get a field by name. Return None if the field does not exist.

source

pub fn merge<S: TryInto<Self, Error = Error>>(&self, other: S) -> Result<Self>

Merge this schema from the other schema.

After merging, the field IDs from other schema will be reassigned, following the fields in self.