Error

Enum Error 

pub enum Error {
Show 31 variants InvalidInput { source: Box<dyn Error + Sync + Send>, location: Location, }, DatasetAlreadyExists { uri: String, location: Location, }, SchemaMismatch { difference: String, location: Location, }, DatasetNotFound { path: String, source: Box<dyn Error + Sync + Send>, location: Location, }, CorruptFile { path: Path, source: Box<dyn Error + Sync + Send>, location: Location, }, NotSupported { source: Box<dyn Error + Sync + Send>, location: Location, }, CommitConflict { version: u64, source: Box<dyn Error + Sync + Send>, location: Location, }, RetryableCommitConflict { version: u64, source: Box<dyn Error + Sync + Send>, location: Location, }, TooMuchWriteContention { message: String, location: Location, }, Internal { message: String, location: Location, }, PrerequisiteFailed { message: String, location: Location, }, Unprocessable { message: String, location: Location, }, Arrow { message: String, location: Location, }, Schema { message: String, location: Location, }, NotFound { uri: String, location: Location, }, IO { source: Box<dyn Error + Sync + Send>, location: Location, }, Index { message: String, location: Location, }, IndexNotFound { identity: String, location: Location, }, InvalidTableLocation { message: String, }, Stop, Wrapped { error: Box<dyn Error + Sync + Send>, location: Location, }, Cloned { message: String, location: Location, }, Execution { message: String, location: Location, }, InvalidRef { message: String, }, RefConflict { message: String, }, RefNotFound { message: String, }, Cleanup { message: String, }, VersionNotFound { message: String, }, VersionConflict { message: String, major_version: u16, minor_version: u16, location: Location, }, Namespace { source: Box<dyn Error + Sync + Send>, location: Location, }, External { source: Box<dyn Error + Sync + Send>, },
}

Variants



InvalidInput

Fields

source: Box<dyn Error + Sync + Send>
location: Location


DatasetAlreadyExists

Fields

location: Location


SchemaMismatch

Fields

difference: String
location: Location


DatasetNotFound

Fields

path: String
source: Box<dyn Error + Sync + Send>
location: Location


CorruptFile

Fields

path: Path
source: Box<dyn Error + Sync + Send>
location: Location


NotSupported

Fields

source: Box<dyn Error + Sync + Send>
location: Location


CommitConflict

Fields

version: u64
source: Box<dyn Error + Sync + Send>
location: Location


RetryableCommitConflict

Fields

version: u64
source: Box<dyn Error + Sync + Send>
location: Location


TooMuchWriteContention

Fields

message: String
location: Location


Internal

Fields

message: String
location: Location


PrerequisiteFailed

Fields

message: String
location: Location


Unprocessable

Fields

message: String
location: Location


Arrow

Fields

message: String
location: Location


Schema

Fields

message: String
location: Location


NotFound

Fields

location: Location


IO

Fields

source: Box<dyn Error + Sync + Send>
location: Location


Index

Fields

message: String
location: Location


IndexNotFound

Fields

identity: String
location: Location


InvalidTableLocation

Fields

message: String


Stop

Stream early stop



Wrapped

Fields

error: Box<dyn Error + Sync + Send>
location: Location


Cloned

Fields

message: String
location: Location


Execution

Fields

message: String
location: Location


InvalidRef

Fields

message: String


RefConflict

Fields

message: String


RefNotFound

Fields

message: String


Cleanup

Fields

message: String


VersionNotFound

Fields

message: String


VersionConflict

Fields

message: String
major_version: u16
minor_version: u16
location: Location


Namespace

Fields

source: Box<dyn Error + Sync + Send>
location: Location


External

External error passed through from user code.

This variant preserves errors that users pass into Lance APIs (e.g., via streams with custom error types). The original error can be recovered using Error::into_external or inspected using Error::external_source.

Fields

source: Box<dyn Error + Sync + Send>

Implementations

Source

impl Error

pub fn corrupt_file( path: Path, message: impl Into<String>, location: Location, ) -> Error

pub fn invalid_input(message: impl Into<String>, location: Location) -> Error

pub fn io(message: impl Into<String>, location: Location) -> Error

pub fn version_conflict( message: impl Into<String>, major_version: u16, minor_version: u16, location: Location, ) -> Error

pub fn not_found(uri: impl Into<String>) -> Error

pub fn schema(message: impl Into<String>, location: Location) -> Error

pub fn not_supported(message: impl Into<String>, location: Location) -> Error

pub fn external(source: Box<dyn Error + Sync + Send>) -> Error

Create an External error from a boxed error source.

pub fn external_source(&self) -> Option<&Box<dyn Error + Sync + Send>>

Returns a reference to the external error source if this is an External variant.

This allows downcasting to recover the original error type.

pub fn into_external(self) -> Result<Box<dyn Error + Sync + Send>, Error>

Consumes the error and returns the external source if this is an External variant.

Returns Err(self) if this is not an External variant, allowing for chained handling.