pub async fn open_dataset<T: AsRef<str>>(table_uri: T) -> Result<Dataset>Expand description
Creates and loads a Dataset from the given path.
Infers the storage backend to use from the scheme in the given table path.
For more advanced configurations use DatasetBuilder.