Module index

Module index 

Secondary Index

Re-exports

pub use crate::index::vector::LogicalIvfView;
pub use crate::index::vector::LogicalVectorIndex;

Modules

frag_reuse
mem_wal
MemWAL Index operations.
prefilter
Secondary Index pre-filter
scalar
Utilities for integrating scalar indices with datasets
vector
Vector Index for Fast Approximate Nearest Neighbor (ANN) Search

Structs

CreateIndexBuilder
FragReuseIndexCacheKey
IndexSegment
A single physical segment of a logical index.
MemWalCacheKey
NoopIndexBuildProgress
ScalarIndexInfo
Snapshot of every scalar index on a dataset, captured at planning time and consumed by the scalar/aggregate pushdown machinery.

Traits

DatasetIndexExt
Extends crate::Dataset with secondary index APIs.
DatasetIndexInternalExt
A trait for internal dataset utilities
FilterLoader
A trait to be implemented by anything supplying a prefilter row addr mask
IndexBuildProgress
Progress callback for index building and distributed index finalization.
IndexBuilder
Builds index.
IndexDescription
Additional information about an index
IndexParams
IntoIndexSegment
Convert an existing index segment representation into IndexSegment.
PreFilter
 Filter out row ids that we know are not relevant to the query.