Secondary Index
Re-exports
pub use crate::index::vector::LogicalIvfView;pub use crate::index::vector::LogicalVectorIndex;
Modules
- frag_
reuse - mem_wal
- MemWAL Index operations.
- prefilter
- Secondary Index pre-filter
- scalar
- Utilities for integrating scalar indices with datasets
- vector
- Vector Index for Fast Approximate Nearest Neighbor (ANN) Search
Structs
- Create
Index Builder - Frag
Reuse Index Cache Key - Index
Segment - A single physical segment of a logical index.
- MemWal
Cache Key - Noop
Index Build Progress - Scalar
Index Info - Snapshot of every scalar index on a dataset, captured at planning time and consumed by the scalar/aggregate pushdown machinery.
Traits
- Dataset
Index Ext - Extends
crate::Datasetwith secondary index APIs. - Dataset
Index Internal Ext - A trait for internal dataset utilities
- Filter
Loader - A trait to be implemented by anything supplying a prefilter row addr mask
- Index
Build Progress - Progress callback for index building and distributed index finalization.
- Index
Builder - Builds index.
- Index
Description - Additional information about an index
- Index
Params - Into
Index Segment - Convert an existing index segment representation into
IndexSegment. - PreFilter
- Filter out row ids that we know are not relevant to the query.