pub trait DatasetIndexInternalExt: DatasetIndexExt {
// Required methods
fn open_generic_index<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
column: &'life1 str,
uuid: &'life2 Uuid,
metrics: &'life3 dyn MetricsCollector,
) -> Pin<Box<dyn Future<Output = Result<Arc<dyn Index>>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait;
fn open_scalar_index<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
column: &'life1 str,
uuid: &'life2 Uuid,
metrics: &'life3 dyn MetricsCollector,
) -> Pin<Box<dyn Future<Output = Result<Arc<dyn ScalarIndex>>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait;
fn open_vector_index<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
column: &'life1 str,
uuid: &'life2 Uuid,
metrics: &'life3 dyn MetricsCollector,
) -> Pin<Box<dyn Future<Output = Result<Arc<dyn VectorIndex>>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait;
fn open_logical_vector_index<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
column: &'life1 str,
name: &'life2 str,
) -> Pin<Box<dyn Future<Output = Result<LogicalVectorIndex>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait;
fn open_frag_reuse_index<'life0, 'life1, 'async_trait>(
&'life0 self,
metrics: &'life1 dyn MetricsCollector,
) -> Pin<Box<dyn Future<Output = Result<Option<Arc<FragReuseIndex>>>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
fn open_mem_wal_index<'life0, 'life1, 'async_trait>(
&'life0 self,
metrics: &'life1 dyn MetricsCollector,
) -> Pin<Box<dyn Future<Output = Result<Option<Arc<MemWalIndex>>>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
fn frag_reuse_index_uuid<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Option<Uuid>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn scalar_index_info<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<ScalarIndexInfo>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn unindexed_fragments<'life0, 'life1, 'async_trait>(
&'life0 self,
idx_name: &'life1 str,
) -> Pin<Box<dyn Future<Output = Result<Vec<Fragment>>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
fn indexed_fragments<'life0, 'life1, 'async_trait>(
&'life0 self,
idx_name: &'life1 str,
) -> Pin<Box<dyn Future<Output = Result<Vec<Vec<Fragment>>>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
fn initialize_index<'life0, 'life1, 'life2, 'async_trait>(
&'life0 mut self,
source_dataset: &'life1 Dataset,
index_name: &'life2 str,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait;
fn initialize_indices<'life0, 'life1, 'async_trait>(
&'life0 mut self,
source_dataset: &'life1 Dataset,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
}Expand description
A trait for internal dataset utilities
Internal use only. No API stability guarantees.
Required Methods
Sourcefn open_generic_index<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
column: &'life1 str,
uuid: &'life2 Uuid,
metrics: &'life3 dyn MetricsCollector,
) -> Pin<Box<dyn Future<Output = Result<Arc<dyn Index>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
fn open_generic_index<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
column: &'life1 str,
uuid: &'life2 Uuid,
metrics: &'life3 dyn MetricsCollector,
) -> Pin<Box<dyn Future<Output = Result<Arc<dyn Index>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
Opens an index (scalar or vector) as a generic index
Sourcefn open_scalar_index<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
column: &'life1 str,
uuid: &'life2 Uuid,
metrics: &'life3 dyn MetricsCollector,
) -> Pin<Box<dyn Future<Output = Result<Arc<dyn ScalarIndex>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
fn open_scalar_index<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
column: &'life1 str,
uuid: &'life2 Uuid,
metrics: &'life3 dyn MetricsCollector,
) -> Pin<Box<dyn Future<Output = Result<Arc<dyn ScalarIndex>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
Opens the requested scalar index
Sourcefn open_vector_index<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
column: &'life1 str,
uuid: &'life2 Uuid,
metrics: &'life3 dyn MetricsCollector,
) -> Pin<Box<dyn Future<Output = Result<Arc<dyn VectorIndex>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
fn open_vector_index<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
column: &'life1 str,
uuid: &'life2 Uuid,
metrics: &'life3 dyn MetricsCollector,
) -> Pin<Box<dyn Future<Output = Result<Arc<dyn VectorIndex>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
Opens the requested vector index
Sourcefn open_logical_vector_index<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
column: &'life1 str,
name: &'life2 str,
) -> Pin<Box<dyn Future<Output = Result<LogicalVectorIndex>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
fn open_logical_vector_index<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
column: &'life1 str,
name: &'life2 str,
) -> Pin<Box<dyn Future<Output = Result<LogicalVectorIndex>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Opens all segments for one logical vector index and returns a materialized snapshot.
Sourcefn open_frag_reuse_index<'life0, 'life1, 'async_trait>(
&'life0 self,
metrics: &'life1 dyn MetricsCollector,
) -> Pin<Box<dyn Future<Output = Result<Option<Arc<FragReuseIndex>>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn open_frag_reuse_index<'life0, 'life1, 'async_trait>(
&'life0 self,
metrics: &'life1 dyn MetricsCollector,
) -> Pin<Box<dyn Future<Output = Result<Option<Arc<FragReuseIndex>>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Opens the fragment reuse index
Sourcefn open_mem_wal_index<'life0, 'life1, 'async_trait>(
&'life0 self,
metrics: &'life1 dyn MetricsCollector,
) -> Pin<Box<dyn Future<Output = Result<Option<Arc<MemWalIndex>>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn open_mem_wal_index<'life0, 'life1, 'async_trait>(
&'life0 self,
metrics: &'life1 dyn MetricsCollector,
) -> Pin<Box<dyn Future<Output = Result<Option<Arc<MemWalIndex>>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Opens the MemWAL index
Sourcefn frag_reuse_index_uuid<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Option<Uuid>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn frag_reuse_index_uuid<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Option<Uuid>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Gets the fragment reuse index UUID from the current manifest, if it exists
Sourcefn scalar_index_info<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<ScalarIndexInfo>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn scalar_index_info<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<ScalarIndexInfo>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Loads information about all the available scalar indices on the dataset
Sourcefn unindexed_fragments<'life0, 'life1, 'async_trait>(
&'life0 self,
idx_name: &'life1 str,
) -> Pin<Box<dyn Future<Output = Result<Vec<Fragment>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn unindexed_fragments<'life0, 'life1, 'async_trait>(
&'life0 self,
idx_name: &'life1 str,
) -> Pin<Box<dyn Future<Output = Result<Vec<Fragment>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Return the fragments that are not covered by any of the deltas of the index.
Sourcefn indexed_fragments<'life0, 'life1, 'async_trait>(
&'life0 self,
idx_name: &'life1 str,
) -> Pin<Box<dyn Future<Output = Result<Vec<Vec<Fragment>>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn indexed_fragments<'life0, 'life1, 'async_trait>(
&'life0 self,
idx_name: &'life1 str,
) -> Pin<Box<dyn Future<Output = Result<Vec<Vec<Fragment>>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Return the fragments that are covered by each of the deltas of the index.
Sourcefn initialize_index<'life0, 'life1, 'life2, 'async_trait>(
&'life0 mut self,
source_dataset: &'life1 Dataset,
index_name: &'life2 str,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
fn initialize_index<'life0, 'life1, 'life2, 'async_trait>(
&'life0 mut self,
source_dataset: &'life1 Dataset,
index_name: &'life2 str,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Initialize a specific index on this dataset based on an index from a source dataset.
Sourcefn initialize_indices<'life0, 'life1, 'async_trait>(
&'life0 mut self,
source_dataset: &'life1 Dataset,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn initialize_indices<'life0, 'life1, 'async_trait>(
&'life0 mut self,
source_dataset: &'life1 Dataset,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Initialize all indices on this dataset based on indices from a source dataset.
This will call initialize_index for each non-system index in the source dataset.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".