Vector Index for Fast Approximate Nearest Neighbor (ANN) Search
Modules
Structs
- Logical
IvfView - An IVF-specific inspection and maintenance view over a
LogicalVectorIndex. - Logical
Vector Index - A materialized snapshot of one logical vector index and all of its segments.
- Vector
Index Params - The parameters to build vector index.
Enums
- Index
File Version - Stage
Params - Parameters of each index stage.
Constants
Functions
- initialize_
vector_ index - Initialize a vector index from a source dataset This will reuse the centroids from the source dataset, making the new indices basically a “delta index” of the source dataset, until the new dataset fully retains the index.