Execution nodes
WARNING: Internal API with no stability guarantees.
Re-exports
pub use utils::PreFilterSource;
Modules
Structs
- ANNIvf
Partition Exec - ExecutionPlan to execute the find the closest IVF partitions.
- ANNIvf
SubIndex Exec - Datafusion ExecutionPlan to run search on vector index partitions.
- AddRow
Addr Exec - Add a
_rowaddrcolumn to a stream of record batches that have a_rowid. - AddRow
Offset Exec - Add a
_rowoffsetcolumn to a stream of record batches that have a_rowaddrcolumn. - Filter
Plan - KNNVector
Distance Exec - ExecutionPlan compute vector distance from a query vector.
- Lance
Filter Exec - Lance
Pushdown Scan Exec - Lance
Scan Config - Lance
Scan Exec - DataFusion ExecutionPlan for scanning one Lance dataset
- Planner
- Scan
Config - Take
Exec
Functions
- get_
physical_ optimizer - project
- Make a DataFusion projection node from a schema.