pub struct ANNIvfSubIndexExec { /* private fields */ }Expand description
Datafusion ExecutionPlan to run search on vector index partitions.
A IVF-{PQ/SQ/HNSW} query plan is:
AnnSubIndexExec: k=10
AnnPartitionExec: nprobes=20The partition index returns one batch per delta with maximum_nprobes partitions in sorted order.
The sub-index then runs a KNN search on each partition in parallel.
First, the index will search minimum_probes partitions on each delta. If there are enough results
at that point to satisfy K then the results will be sorted and returned.
If there are not enough results then the prefilter will be consulted to determine how many potential results exist. If the number is smaller than K then those additional results will be fetched directly and given maximum distance.
If the number of results is larger then additional partitions will be searched in batches of
cpu_parallelism until min(K, num_filtered_results) are found or maximum_nprobes partitions
have been searched.
TODO: In the future, if we can know that a filter will be highly selective (through cost estimation or user-provided hints) we wait for the prefilter results before we load any partitions. If there are less than K (or some threshold) results then we can return without search.
Implementations
Sourceimpl ANNIvfSubIndexExec
impl ANNIvfSubIndexExec
pub fn try_new( input: Arc<dyn ExecutionPlan>, dataset: Arc<Dataset>, indices: Vec<IndexMetadata>, query: Query, prefilter_source: PreFilterSource, ) -> Result<Self>